@@ -506,6 +506,11 @@ if [ -n "$(list-devices cd; list-devices maybe-usb-floppy)" ]; then
 	apt-install eject || true
 fi
 
+# Install opal-prd for OpenPOWER machines LP: #1555904
+if [ -d /sys/firmware/devicetree/base/ibm,opal/diagnostics ]; then
+	apt-install opal-prd || true
+fi
+
 db_progress SET $MAX_STEPS
 db_progress STOP
 
